@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 # Copyright (C) 2013, Cameron White
 from pkg_resources import resource_filename
-from .. import TOKEN_PATH
+from .. import CONFIG_PATH
 from .tools import waiting_effects
 from ..tools import load_token, store_token, generate_tokens
 from github import Github
@@ -161,7 +161,8 @@ class MainWidget(QMainWindow):
         # Update
 
         self.loadUserMenu()
-        self.activeUserAction.setVisible(False)
+        if self.activeUserAction:
+            self.activeUserAction.setVisible(False)
         self.authenticate()
         self.actionsUpdate()
         self.reposRefresh()
@@ -187,7 +188,7 @@ class MainWidget(QMainWindow):
     def loadUserMenu(self):
         
         action = None
-        for _, username, token in generate_tokens(TOKEN_PATH, 'github'):
+        for _, username, token in generate_tokens(CONFIG_PATH, 'github'):
             
             try:
                 url = Github(token).get_user().avatar_url
@@ -273,8 +274,8 @@ class MainWidget(QMainWindow):
             imageLabel.setMargin(5)
 
             self.starsTableWidget.setCellWidget(row, 0, imageLabel)
-            label = QLabel('<b>{}/{}</b><br />{}'.format(
-                str(repo.owner.login), str(repo.name), str(repo.description)))
+            label = QLabel(u'<b>{}/{}</b><br />{}'.format(
+                unicode(repo.owner.login), unicode(repo.name), unicode(repo.description)))
             label.setAlignment(Qt.AlignVCenter)
             label.setMargin(5)
             label.setWordWrap(True)
@@ -291,12 +292,13 @@ class MainWidget(QMainWindow):
     @waiting_effects
     def authenticate(self):
         
-        username = str(self.activeUserAction.text())
-        try:
-            token = load_token(TOKEN_PATH, 'github', username) 
+        if self.activeUserAction:
+            username = str(self.activeUserAction.text())
+            token = load_token(CONFIG_PATH, 'github', username) 
             self.github = Github(token)
-        except IOError, EOFError:
+        else:
             self.github = None
+
     
     def actionsUpdate(self):
         # TODO disable if no user is logged in
@@ -317,7 +319,7 @@ class MainWidget(QMainWindow):
         if wizard.exec_():
             username = str(wizard.field('username').toString())
             token = str(wizard.field('token').toString())
-            store_token(TOKEN_PATH, 'github', username, token)
+            store_token(CONFIG_PATH, 'github', username, token)
             self.authenticate()
             self.reposRefresh()
             self.updateImage()
